@@ -145,12 +145,14 @@ class MagicBoxApi(object):
                          port_name,
                          set_l: float,
                          is_queued=True,
-                         iswait_forfinish=True):
+                         iswait_forfinish=True,
+                         timeout=30000):
         return self.__dobotlink.MagicBox.SetPTPWithLCmd(
             portName=port_name,
             l=set_l,
             isQueued=is_queued,
-            isWaitForFinish=iswait_forfinish)
+            isWaitForFinish=iswait_forfinish,
+            timeout=timeout)
 
     def set_iomultiplexing(self,
                            port_name,
@@ -261,7 +263,7 @@ class MagicBoxApi(object):
 
     def get_infrared_sensor(self, port_name, port: int, is_queued=False):
         return self.__dobotlink.MagicBox.GetInfraredSensor(portName=port_name,
-                                                           port=port,
+                                                           port=port-1,
                                                            isQueued=is_queued)
 
     def set_homecmd(self,
