@@ -416,7 +416,7 @@ class MagicianApi(object):
 
     def set_rcmd(self,
                  port_name,
-                 r: int,
+                 r,
                  is_queued=True,
                  is_wait=True,
                  time_out=5000):
@@ -629,7 +629,7 @@ class MagicianApi(object):
                          version: int,
                          is_queued=False):
         return self.__dobotlink.Magician.SetColorSensor(portName=port_name,
-                                                        port=port-1,
+                                                        port=port - 1,
                                                         enable=enable,
                                                         version=version,
                                                         isQueued=is_queued)
@@ -645,7 +645,7 @@ class MagicianApi(object):
                             version: int,
                             is_queued=False):
         return self.__dobotlink.Magician.SetInfraredSensor(portName=port_name,
-                                                           port=port-1,
+                                                           port=port - 1,
                                                            enable=enable,
                                                            version=version,
                                                            isQueued=is_queued)
@@ -756,3 +756,8 @@ class MagicianApi(object):
     def get_anglesensorstatic_error(self, port_name, is_queued=False):
         return self.__dobotlink.Magician.GetAngleSensorStaticError(
             portName=port_name, isQueued=is_queued)
+
+    def set_waitcmd(self, port_name, delay):
+        return self.__dobotlink.Magician.SetWAITCmd(portName=port_name,
+                                                    delay=delay,
+                                                    timeout=delay + 500)
