@@ -4,4 +4,4 @@ loggers = Loggers()
 
 loggers.set_level(loggers.INFO)
 
-__all__ = ("loggers",)
+__all__ = ("loggers")
